PdfImageColor enum

What an image's decoded samples mean.

Inheritance
Available extensions

Values

bilevel → const PdfImageColor

A stencil mask or a 1-bit gray image.

gray → const PdfImageColor

One component.

rgb → const PdfImageColor

Three components.

cmyk → const PdfImageColor

Four components.

other → const PdfImageColor

Lab, Separation, DeviceN, Pattern, or an unparsable base.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PdfImageColor>
A constant List of the values in this enum, in order of their declaration.