PdfRenderSize class

Output size constraint for rendering.

Constructors

PdfRenderSize({required int maxWidth, required int maxHeight})
Creates a render size constraint.
const
PdfRenderSize.thumbnail(int size)
Creates a square thumbnail constraint.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxHeight int
Maximum output height in pixels.
final
maxWidth int
Maximum output width in pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited