PdfEncryptionConfig class
Apply new encryption with explicit parameters.
- Inheritance
-
- Object
- PdfEncryption
- PdfEncryptionConfig
Constructors
- PdfEncryptionConfig({required String ownerPassword, String userPassword = '', PdfEncryptionAlgorithm algorithm = PdfEncryptionAlgorithm.aes256, PdfPermissions permissions = const PdfPermissions.all()})
-
Creates an encryption configuration.
const
Properties
- algorithm → PdfEncryptionAlgorithm
-
Encryption algorithm to use.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownerPassword → String
-
Owner password (full access).
final
- permissions → PdfPermissions
-
Access permissions for the user password.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userPassword → String
-
User password (restricted by permissions).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited