PdfSaveIncremental class
Incremental save — append-only, preserves signatures.
- Inheritance
-
- Object
- PdfSaveOptions
- PdfSaveIncremental
Constructors
- PdfSaveIncremental()
-
Creates incremental save options.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited